/*
 * Copyright 2013 Andrea "andynaz" Agnesse
 *
 * This file is part of "andyLib".
 *
 * "andyLib" is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * "andyLib" is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * "andyLib".  If not, see <http://www.gnu.org/licenses/>.
 *
 * author e-mail: andynaz@gmail.com
 * author home page: http://andynaz.altervista.org
 * program official page: http://andynaz.altervista.org/Progetti/andyLib.shtm
 */

package it.andynaz.log;

import java.io.*;
import it.andynaz.utils.*;

/**
 * File Logger.
 * 
 * Writes the logs on a text file.
 * 
 * <p>Each constructor calls the corresponding constructor of the {@link Logger}
 * class, so that FileLogger objects inherits alla the properties the Logger
 * class has.
 * 
 * @author andynaz
 * @version 2013/01/14
 */
public class FileLogger extends Logger{

	/**
	 * File in which write the logs.
	 */
	protected File logFile = new File("andyLog.log");
	
	/**
	 * Creates a FileLogger with a name and a configuration.
	 * 
	 * <p>The path of the file in which write the logs is taken from the property
	 * "fileLogger.file".</p>
	 * 
	 * @param name name of the Logger
	 * @param conf configuration of the Logger
	 */
	public FileLogger(String name, Config conf){
		super(name, conf);

		// --- file
		if( conf.getProperty("fileLogger.file")!=null ){
			try{
				this.logFile = new File(conf.getProperty("fileLogger.file"));
			} catch(Exception e){ /*out.println("err: data"); throw e;*/ }
		}
	}
	
	/**
	 * Creates a FileLogger with a name.
	 *
	 * The configuration used is the shared one.
	 *
	 * @param name name of the Logger
	 */
	public FileLogger(String name){
		this(name, Config.getConfig());
	}
	
	/**
	 * Creates a FileLogger with a configuration.
	 *
	 * @param conf configuration of the Logger
	 */
	public FileLogger(Config conf){
		this(null, conf);
	}
	
	/**
	 * Creates a FileLogger.
	 *
	 * The configuration used is the shared one.
	 */
	public FileLogger(File logFile){
		this(null, Config.getConfig());
	}
	
	
	/**
	 * Writes the log.
	 * 
	 * If it is not possible, invokes the {@link
	 * Logger#log(java.lang.String, it.andynaz.log.Level)} method.
	 * 
	 * @param log log to be written
	 * @param level log level
	 */
	@Override
	public void log(String log, Level level){
		if( this.level.hasToLog(level) ){
			try{
				Writer w = new FileWriter(logFile, true);
				BufferedWriter bw = new BufferedWriter(w);
				bw.write(getPrefix() + log);
				bw.newLine();
				bw.flush();
				bw.close();
			} catch(IOException e){
				Utils.printException("error while writing the log", e);
				super.log(log, level);
			}
		}
	}
	
}
